From e0dc711c2b2dc4e2ec397d7f53910f11e1ca4ade Mon Sep 17 00:00:00 2001
From: mcramer <m.cramer@pixcept.de>
Date: Mon, 02 Sep 2013 04:14:56 -0400
Subject: [PATCH] - Changed previous commit to check for read permissions only on download action
---
interface/web/sites/web_domain_list.php | 23 ++++++++++++-----------
1 files changed, 12 insertions(+), 11 deletions(-)
diff --git a/interface/web/sites/web_domain_list.php b/interface/web/sites/web_domain_list.php
index edc7e7f..d9c5066 100644
--- a/interface/web/sites/web_domain_list.php
+++ b/interface/web/sites/web_domain_list.php
@@ -41,18 +41,19 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
- header("Location: ../index.php");
- exit;
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
+
+$app->load('listform_actions');
+
+
+class list_action extends listform_actions {
+
}
-$app->uses('listform_actions');
-
-// Limit the results to alias domains
-// $app->listform_actions->SQLExtWhere = "type = 'local'";
-
-$app->listform_actions->onLoad();
-
+$list = new list_action;
+$list->SQLExtWhere = "web_domain.type = 'vhost' AND web_domain.parent_domain_id = '0'";
+$list->SQLOrderBy = 'ORDER BY web_domain.domain';
+$list->onLoad();
?>
\ No newline at end of file
--
Gitblit v1.9.1